@@ -3,21 +3,26 @@
 import urllib.request, json
 import os
 import argparse
+from dulwich.repo import Repo
+
 from .version import __version__
 
 def main():
   parser = argparse.ArgumentParser(description='Launchable CLI')
   parser.add_argument('-v', '--version', action='version', version=__version__)
-
   subparsers = parser.add_subparsers()
 
-  parser_add = subparsers.add_parser('commit', help='see `commit -h`')
-  parser_add.add_argument('--path', help="repository path", default="$(pwd)", type=str)
+  subparsers = subparsers.add_parser('record', help='see `record -h`')
+
+  subsubparsers = subparsers.add_subparsers()
+
+  parser_add = subsubparsers.add_parser('commit', help='see `commit -h`')
+  parser_add.add_argument('--source', help="repository path", default="$(pwd)", type=str)
   parser_add.set_defaults(handler=commit)
 
-  parser_add = subparsers.add_parser('build', help='see `build -h`')
-  parser_add.add_argument('--build', help='build number', required=True, type=str, metavar='BUILD_NUMBER')
-  parser_add.add_argument('--commit', help='repository name and its commit hash. please specify repoName=hash pair like --commit .=3e8f79eeab55e0b79d1e6f5202982229cee59928 --commit moduleA=7c9cb22ffaf0732306d243ebc7c0951246aab5c1', required=True, action='append', metavar="REPO_NAME=COMMIT_HASH")
+  parser_add = subsubparsers.add_parser('build', help='see `build -h`')
+  parser_add.add_argument('--name', help='build identifer', required=True, type=str, metavar='BUILD_ID')
+  parser_add.add_argument('--source', help='repository name and its commit hash. please specify repoName=hash pair like --source . --source ./moduleA', required=True, action='append', metavar="REPO_NAME")
   parser_add.set_defaults(handler=build)
 
   args = parser.parse_args()
@@ -37,24 +42,23 @@ def _parse_token():
 
 def commit(args):
   token, org, workspace = _parse_token()
-  path = args.path
-  os.system("docker run -u $(id -u) -i --rm -v {}:{} --env LAUNCHABLE_TOKEN launchableinc/ingester:latest ingest:commit {}".format(path,path,path))
+  source = args.source
+  os.system("docker run -u $(id -u) -i --rm -v {}:{} --env LAUNCHABLE_TOKEN launchableinc/ingester:latest ingest:commit {}".format(source ,source, source))
 
 def build(args):
   token, org, workspace = _parse_token()
-  build = args.build
-  commit = args.commit
+  name = args.name
+  sources = args.source
   try:
-    commitHashes = [{ 'repositoryName': repo, 'commitHash': hash } for (repo, hash) in (pair.split('=') for pair in commit)]
+    commitHashes = [{ 'repositoryName': source, 'commitHash': Repo(source).head().decode('ascii') } for source in sources]
     if not (commitHashes[0]['repositoryName'] and commitHashes[0]['commitHash']):
-      exit('Please specify --commit as --commit .=3e8f79eeab55e0b79d1e6f5202982229cee59928')
+      exit('Please specify --source as --source .')
 
     payload = {
-      "buildNumber": build,
+      "buildNumber": name,
       "commitHashes": commitHashes
     }
 
-
     headers = {
       "Content-Type" : "application/json",
       'Authorization': 'Bearer {}'.format(token)
